
From: Dominik Brodowski <linux@dominikbrodowski.net>

Remove the old "detach" mechanism as it is unused now.

Signed-off-by: Dominik Brodowski <linux@dominikbrodowski.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/pcmcia/ds.c |   77 +++++++++++-----------------------------------------
 include/pcmcia/cs.h |    1 
 include/pcmcia/ds.h |    1 
 3 files changed, 17 insertions(+), 62 deletions(-)

diff -puN drivers/pcmcia/ds.c~pcmcia-remove-old-two-step-removal-mechanism drivers/pcmcia/ds.c
--- 25/drivers/pcmcia/ds.c~pcmcia-remove-old-two-step-removal-mechanism	Wed Sep  7 16:00:44 2005
+++ 25-akpm/drivers/pcmcia/ds.c	Wed Sep  7 16:00:44 2005
@@ -402,43 +402,29 @@ static int pcmcia_device_remove(struct d
 	/* detach the "instance" */
 	p_dev = to_pcmcia_dev(dev);
 	p_drv = to_pcmcia_drv(dev->driver);
+	if (!p_drv)
+		return 0;
 
-	/* the likely, new path */
-	if (p_drv && p_drv->remove) {
+	if (p_drv->remove)
 	       	p_drv->remove(p_dev);
 
-		/* check for proper unloading */
-		if (p_dev->state & (CLIENT_IRQ_REQ|CLIENT_IO_REQ|CLIENT_CONFIG_LOCKED))
-			printk(KERN_INFO "pcmcia: driver %s did not release config properly\n",
-			       p_drv->drv.name);
+	/* check for proper unloading */
+	if (p_dev->state & (CLIENT_IRQ_REQ|CLIENT_IO_REQ|CLIENT_CONFIG_LOCKED))
+		printk(KERN_INFO "pcmcia: driver %s did not release config properly\n",
+		       p_drv->drv.name);
 
-		for (i = 0; i < MAX_WIN; i++)
-			if (p_dev->state & CLIENT_WIN_REQ(i))
-				printk(KERN_INFO "pcmcia: driver %s did not release windows properly\n",
-				       p_drv->drv.name);
-
-		/* undo pcmcia_register_client */
-		p_dev->state = CLIENT_UNBOUND;
-		pcmcia_put_dev(p_dev);
-
-		/* references from pcmcia_probe_device */
-		pcmcia_put_dev(p_dev);
-		module_put(p_drv->owner);
+	for (i = 0; i < MAX_WIN; i++)
+		if (p_dev->state & CLIENT_WIN_REQ(i))
+			printk(KERN_INFO "pcmcia: driver %s did not release windows properly\n",
+			       p_drv->drv.name);
 
-		return 0;
-	}
+	/* undo pcmcia_register_client */
+	p_dev->state = CLIENT_UNBOUND;
+	pcmcia_put_dev(p_dev);
 
-	/* old path */
-	if (p_drv) {
-		if ((p_drv->detach) && (p_dev->instance)) {
-			printk(KERN_INFO "pcmcia: using deprecated detach mechanism. Fix the driver!\n");
-
-			p_drv->detach(p_dev->instance);
-			/* from pcmcia_probe_device */
-			put_device(&p_dev->dev);
-		}
-		module_put(p_drv->owner);
-	}
+	/* references from pcmcia_probe_device */
+	pcmcia_put_dev(p_dev);
+	module_put(p_drv->owner);
 
 	return 0;
 }
@@ -1231,35 +1217,6 @@ int pcmcia_register_client(struct pcmcia
 EXPORT_SYMBOL(pcmcia_register_client);
 
 
-int pcmcia_deregister_client(struct pcmcia_device *p_dev)
-{
-	struct pcmcia_socket *s;
-	int i;
-
-	s = p_dev->socket;
-	ds_dbg(1, "deregister_client(%p)\n", p_dev);
-
-	if (p_dev->state & (CLIENT_IRQ_REQ|CLIENT_IO_REQ|CLIENT_CONFIG_LOCKED))
-		goto warn_out;
-	for (i = 0; i < MAX_WIN; i++)
-		if (p_dev->state & CLIENT_WIN_REQ(i))
-			goto warn_out;
-
-	if (p_dev->state & CLIENT_STALE) {
-		p_dev->state &= ~CLIENT_STALE;
-		pcmcia_put_dev(p_dev);
-	} else {
-		p_dev->state = CLIENT_UNBOUND;
-	}
-
-	return CS_SUCCESS;
- warn_out:
-	printk(KERN_WARNING "ds: deregister_client was called too early.\n");
-	return CS_IN_USE;
-} /* deregister_client */
-EXPORT_SYMBOL(pcmcia_deregister_client);
-
-
 static struct pcmcia_callback pcmcia_bus_callback = {
 	.owner = THIS_MODULE,
 	.event = ds_event,
diff -puN include/pcmcia/cs.h~pcmcia-remove-old-two-step-removal-mechanism include/pcmcia/cs.h
--- 25/include/pcmcia/cs.h~pcmcia-remove-old-two-step-removal-mechanism	Wed Sep  7 16:00:44 2005
+++ 25-akpm/include/pcmcia/cs.h	Wed Sep  7 16:00:44 2005
@@ -382,7 +382,6 @@ enum service {
 struct pcmcia_socket;
 
 int pcmcia_access_configuration_register(struct pcmcia_device *p_dev, conf_reg_t *reg);
-int pcmcia_deregister_client(struct pcmcia_device *p_dev);
 int pcmcia_get_configuration_info(struct pcmcia_device *p_dev, config_info_t *config);
 int pcmcia_get_first_window(window_handle_t *win, win_req_t *req);
 int pcmcia_get_next_window(window_handle_t *win, win_req_t *req);
diff -puN include/pcmcia/ds.h~pcmcia-remove-old-two-step-removal-mechanism include/pcmcia/ds.h
--- 25/include/pcmcia/ds.h~pcmcia-remove-old-two-step-removal-mechanism	Wed Sep  7 16:00:44 2005
+++ 25-akpm/include/pcmcia/ds.h	Wed Sep  7 16:00:44 2005
@@ -136,7 +136,6 @@ struct pcmcia_driver {
 	dev_link_t		*(*attach)(void);
 	int (*event)		(event_t event, int priority,
 				 event_callback_args_t *);
-	void			(*detach)(dev_link_t *);
 
 	void (*remove)		(struct pcmcia_device *dev);
 
_
